==> sv_v0.01.tgz: supervisor/circmon.tcl <==

# wdata_monit timer identifier: to be able to stop/restart it.
set wdata_after ""
# Poller of the weather general data: autonomous
proc wdata_monit {{delay 1000}} {
	global wdata_after
	cmd METEO get data
	# schedule next monitor body call depending on day/night dissection:
	if {[llength [array names CIRC hsun]] && [CIRC hsun]<0} {
		set delay [METEO pp_data_night]
	} else {
		set delay [METEO pp_data_day]
	}
	set wdata_after [after [expr round($delay*1000)] wdata_monit $delay]
}

#wcond_monit timer identifier:
set wcond_after 0
#Time-keaper of last-detected bad weather conditions in seconds-1969:
set wcond_badtime 0
# Poller of the weather critical condition: depends on hsun_monit
proc wcond_monit {{delay 1000}} {
	global wcond_after wcond_badtime
	cmd METEO get cond
	switch [METEO cond] {
		"GOOD" 
			{
				# can we start observations?: hsun, cond and time-bad_time
				if {[CIRC hsun]<[CIRC hsun_lim] && \
					[expr [clock seconds] - $wcond_badtime]>[METEO waittime] \
					&& ! [is_observations_now]} start_obs 
			}
		"BAD"  
			{ 
				if {[is_observations_now]} stop_obs
				set wcond_badtime [clock seconds]
			}
		default	{ error "Unrecognized meteo COND=[METEO cond]" }
	}

	if {[llength [array names CIRC hsun]] && [CIRC hsun]<[CIRC hsun_lim]} {
		if { [is_observations_now] } {
			set delay [METEO pp_cond_obs]
		} else {
			set delay [METEO pp_cond_nobs]
		}
		# schedule next monitor body call:
		set wcond_after [after [expr round($delay*1000)] wcond_monit $delay]
	}
	# else - do not restart until next external start by hsun_monit
}

#hsun_monit timer identifier:
set hsun_after ""
# Poller of the sun altitude: starts/stops wcond_monit
proc hsun_monit {{delay 1000}} {
	global wcond_after hsun_after
	cmd CIRC get hsun
	if {[CIRC hsun]<[CIRC hsun_lim]} {
		# start conditions monitor
		if {$wcond_after==0} wcond_monit
	} else {
		# stop observations and conditions monitor
		if {[is_observations_now]} stop_obs
		catch {after cancel $wcond_after; set wcond_after 0}
	}
	if { [CIRC hsun]>0 } {
		set delay [CIRC pp_hsun_day]
	} else {
		set delay [CIRC pp_hsun_night]
	}
	# schedule next monitor body call:
	set hsun_after [after [expr round($delay*1000)] hsun_monit $delay]
}

# start monitors
foreach comp {CIRC METEO} { cmd $comp init}
wdata_monit
hsun_monit

==> sv_v0.02.tgz: supervisor/circmon.tcl <==

# wdata_monit timer identifier: to be able to stop/restart it.
set wdata_after ""
# Poller of the weather general data: autonomous
proc wdata_monit delay {
	global wdata_after
	cmd METEO get data
	# schedule next monitor body call depending on day/night dissection:
	if {[llength [array names CIRC hsun]] && [CIRC hsun]<0} {
		set delay [METEO pp_data_night]
	} else {
		set delay [METEO pp_data_day]
	}
	set wdata_after [after [expr round($delay*1000)] wdata_monit $delay]
}

#wcond_monit timer identifier:
set wcond_after 0
#Time-keaper of last-detected bad weather conditions in seconds-1969:
set wcond_badtime 0
# Poller of the weather critical condition: depends on hsun_monit
proc wcond_monit delay {
	global wcond_after wcond_badtime
	cmd METEO get cond
	switch [METEO cond] {
		"GOOD" 
			{
				# can we start observations?: hsun, cond and time-bad_time
				if {[CIRC hsun]<[CIRC hsun_lim] && \
					[expr [clock seconds] - $wcond_badtime]>[METEO waittime] \
					&& ! [is_observations_now]} start_obs 
			}
		"BAD"  
			{ 
				if {[is_observations_now]} stop_obs
				set wcond_badtime [clock seconds]
			}
		default	{ error "Unrecognized meteo COND=[METEO cond]" }
	}

	if {[llength [array names CIRC hsun]] && [CIRC hsun]<[CIRC hsun_lim]} {
		if { [is_observations_now] } {
			set delay [METEO pp_cond_obs]
		} else {
			set delay [METEO pp_cond_nobs]
		}
		# schedule next monitor body call:
		set wcond_after [after [expr round($delay*1000)] wcond_monit $delay]
	}
	# else - do not restart until next external start by hsun_monit
}

#hsun_monit timer identifier:
set hsun_after ""
# Poller of the sun altitude: starts/stops wcond_monit
proc hsun_monit delay {
	global wcond_after hsun_after
	cmd CIRC get hsun
	if {[CIRC hsun]<[CIRC hsun_lim]} {
		# start conditions monitor
		if {$wcond_after==0} {wcond_monit 1}
	} else {
		# stop observations and conditions monitor
		if {[is_observations_now]} stop_obs
		catch {after cancel $wcond_after; set wcond_after 0}
	}
	if { [CIRC hsun]>0 } {
		set delay [CIRC pp_hsun_day]
	} else {
		set delay [CIRC pp_hsun_night]
	}
	# schedule next monitor body call:
	set hsun_after [after [expr round($delay*1000)] hsun_monit $delay]
}

# start monitors
foreach comp {CIRC METEO} { cmd $comp init}
wdata_monit 1
hsun_monit 1
